textmining

|  | ## Cheshire3: Package textmining

Package textmining

Package textmining |
[hide private]
[frames] | no frames]

## Package textmining
source code

Submodules | [hide private]
textmining.TsujiiC3 textmining.tmDocumentFactory textmining.tmNormalizer textmining.tmPreParser textmining.tmTransformer

Variables | [hide private]
elementType |
myTokenizer |

Variables Details | [hide private]

    ### elementType Value:
        1

    ### myTokenizer Value:
        <textmining.TsujiiC3.SimpleTokenizer instance at 0xb71d1dcc>